# Atmosphere (Atmo)

Atmospheric state to compute air density and local speed of sound (Mach 1). Supports ICAO standard atmosphere by altitude and custom pressure/temperature/humidity.

???+ api "API Documentation"

    [`py_ballisticcalc.conditions.Atmo`][py_ballisticcalc.conditions.Atmo]<br>
